======================
django-rest-email-auth
======================

.. image:: https://img.shields.io/travis/cdriehuys/django-rest-email-auth.svg
    :target: https://travis-ci.org/cdriehuys/django-rest-email-auth

.. image:: https://img.shields.io/codecov/c/github/cdriehuys/django-rest-email-auth.svg
    :target: https://codecov.io/gh/cdriehuys/django-rest-email-auth

.. image:: https://img.shields.io/pypi/v/django-rest-email-auth.svg
    :target: https://pypi.python.org/pypi/django-rest-email-auth/


Important Links
===============

Project Homepage
  https://github.com/cdriehuys/django-rest-email-auth

Documentation
  https://django-rest-email-auth.readthedocs.io


Overview
========

This package provides a simple way to enable authentication with email addresses for a REST API.

Features:
  * Verify user email addresses
  * Authenticate using any of a user's email addresses
  * Registration of new users


License
=======

This project is licensed under the MIT License.


Authors
=======

Chathan Driehuys (chathan@driehuys.com)
